@@ -370,6 +370,33 @@ public:
 
 //  int copy_textfile(const char *filename);
 
+
+  static void show_omp_mpi_state(){
+    int process_num=0;
+    #ifdef USE_MPI_LOTUS
+    MPI_Comm_rank(MPI_COMM_WORLD,&process_num);
+    MPI_Comm_size(MPI_COMM_WORLD,&N_process);
+    if(process_num==0) std::cout<<" ========== MPI: number of process "<<N_process<<" process_num "<<process_num<<std::endl;
+    #else
+    if(process_num==0) std::cout<<" ========== NO USE MPI"<<std::endl;
+    #endif
+
+
+    #ifdef _OPENMP
+    #pragma omp parallel
+    {
+      int N_threads  = omp_get_num_threads();
+      int thread_num = omp_get_thread_num();
+      if(thread_num==0 && process_num==0) 
+        std::cout<<" ========== openMP: number of threads = "<<N_threads<<std::endl;
+    }
+    #else
+    if(process_num==0)
+      std::cout<<" ========== NO USE openMP"<<std::endl;
+    #endif
+
+  }
+
 };
 
 
