@@ -419,9 +419,14 @@ class td_scf(unittest.TestCase):
 
 
 if __name__ == "__main__":
+  try:
+    from mpi4py import MPI
+  except:
+    process_num = lotus_core_hpp.Util_MPI.get_mpi_rank()
+    if process_num==0: print " mpi4py is not installed"
+  lotus_core_hpp.Util_MPI.set_MPI_COMM_LOTUS()
+
   unittest.main()
 
-
-
  
 
